@@ -347,34 +347,13 @@ void save_template_cb(Fl_Widget *, void *) {
   // Save to a PNG file...
   strcpy(ext, ".png");
 
-  FILE *fp;
-
-  if ((fp = fl_fopen(filename, "wb")) == NULL) {
+  errno = 0;
+  if (fl_write_png(filename, pixels, w, h, 3) != 0) {
     delete[] pixels;
     fl_alert("Error writing %s: %s", filename, strerror(errno));
     return;
   }
 
-  png_structp pptr = png_create_write_struct(PNG_LIBPNG_VER_STRING, 0, 0, 0);
-  png_infop iptr = png_create_info_struct(pptr);
-  png_bytep ptr = (png_bytep)pixels;
-
-  png_init_io(pptr, fp);
-  png_set_IHDR(pptr, iptr, w, h, 8, PNG_COLOR_TYPE_RGB, PNG_INTERLACE_NONE,
-               PNG_COMPRESSION_TYPE_DEFAULT, PNG_FILTER_TYPE_DEFAULT);
-  png_set_sRGB(pptr, iptr, PNG_sRGB_INTENT_PERCEPTUAL);
-
-  png_write_info(pptr, iptr);
-
-  for (int i = h; i > 0; i --, ptr += w * 3) {
-    png_write_row(pptr, ptr);
-  }
-
-  png_write_end(pptr, iptr);
-  png_destroy_write_struct(&pptr, &iptr);
-
-  fclose(fp);
-
 #  if 0 // The original PPM output code...
   strcpy(ext, ".ppm");
   fp = fl_fopen(filename, "wb");
@@ -1353,11 +1332,11 @@ public:
   // returns fileno(FILE*):
   // (file must be open, i.e. _fpt must be non-null)
   // *FIXME* we should find a better solution for the 'fileno' issue
-  int fileno() const {
+  int get_fileno() const {
 #ifdef _MSC_VER
     return _fileno(_fpt); // suppress MSVC warning
 #else
-    return ::fileno(_fpt);
+    return fileno(_fpt);
 #endif
   } // non null if file is open
 
@@ -1501,7 +1480,7 @@ shell_pipe_cb(FL_SOCKET, void*) {
     shell_run_terminal->append(line);
   } else {
     // End of file; tell the parent...
-    Fl::remove_fd(s_proc.fileno());
+    Fl::remove_fd(s_proc.get_fileno());
     s_proc.close();
     shell_run_terminal->append("... END SHELL COMMAND ...\n");
   }
@@ -1537,7 +1516,7 @@ do_shell_command(Fl_Return_Button*, void*) {
   }
   shell_run_window->show();
 
-  Fl::add_fd(s_proc.fileno(), shell_pipe_cb);
+  Fl::add_fd(s_proc.get_fileno(), shell_pipe_cb);
 
   while (s_proc.desc()) Fl::wait();
 
