@@ -27,6 +27,8 @@ void Fl_Tree_set_root(Fl_Tree *self, Fl_Tree_Item *newitem);
 
 Fl_Tree_Item *Fl_Tree_add(Fl_Tree *self, const char *name);
 
+Fl_Tree_Item *Fl_Tree_add_item(Fl_Tree *self, const char *name, Fl_Tree_Item *item);
+
 Fl_Tree_Item *Fl_Tree_insert_above(Fl_Tree *self, Fl_Tree_Item *above, const char *name);
 
 Fl_Tree_Item *Fl_Tree_insert(Fl_Tree *self, Fl_Tree_Item *item, const char *name, int pos);
@@ -251,6 +253,10 @@ int Fl_Tree_callback_reason(const Fl_Tree *self);
 
 /* TreeItems */
 
+Fl_Tree_Item *Fl_Tree_Item_new(Fl_Tree *tree, const char *txt);
+
+void Fl_Tree_Item_draw_item_content(Fl_Tree_Item *item, int (*cb)(Fl_Tree_Item *self, int, void *), void *data);
+
 int Fl_Tree_Item_x(const Fl_Tree_Item *self);
 
 int Fl_Tree_Item_y(const Fl_Tree_Item *self);
@@ -411,6 +417,10 @@ Fl_Tree_Item *Fl_Tree_Item_Array_at(Fl_Tree_Item_Array *self, int index);
 
 void Fl_Tree_Item_Array_delete(Fl_Tree_Item_Array *self);
 
+void *Fl_Tree_Item_usericon(const Fl_Tree_Item *self);
+
+void Fl_Tree_Item_set_usericon(Fl_Tree_Item *self, void *val);
+
 #ifdef __cplusplus
 }
 #endif
