@@ -1,4 +1,3 @@
-#![no_std]
 #![allow(non_camel_case_types)]
 #![allow(dead_code)]
 #![allow(non_upper_case_globals)]
@@ -14,7 +13,6 @@ pub mod image;
 pub mod input;
 pub mod menu;
 pub mod misc;
-pub mod output;
 pub mod table;
 pub mod text;
 pub mod tree;
